@@ -1,6 +1,6 @@
 package App::Greple::frame;
 
-our $VERSION = "1.02";
+our $VERSION = "1.03";
 
 =encoding utf-8
 
@@ -42,11 +42,6 @@ Set frame and fold long lines with frame-friendly prefix string.
 Folding width is taken from the terminal.  Or you can specify the
 width by calling B<set> function with module option.
 
-=item B<--set-frame-width>=I<#>
-
-Set frame width.  You have to put this option before B<--frame>
-option.  See B<set> function in L</FUNCTION> section.
-
 =begin comment
 
 =item B<--frame-simple>
@@ -55,11 +50,15 @@ Set frame without folding.
 
 =end comment
 
+=item B<--frame-cols>
+
+Output results in multi-column format to fit the width of the
+terminal.  The number of columns is automatically calculated from the
+terminal width.
+
 =item B<--frame-pages>
 
-Output results in multi-column, paginated format to fit the width of
-the terminal.  The number of columns is automatically calculated from
-the terminal width.
+Output results in multi-column and paginated format.
 
 =begin html
 
@@ -67,6 +66,11 @@ the terminal width.
 
 =end html
 
+=item B<--set-frame-width>=I<#>
+
+Set frame width.  You have to put this option before B<--frame>
+option.  See B<set> function in L</FUNCTION> section.
+
 =back
 
 =begin comment
@@ -133,6 +137,10 @@ use warnings;
 use utf8;
 use Data::Dumper;
 
+$ENV{GREPLE_FRAME_PAGES_WIDTH}    //= '80';
+$ENV{GREPLE_FRAME_PAGES_MARGIN}   //= '0';
+$ENV{GREPLE_FRAME_PAGES_BOUNDARY} //= 'none';
+
 my($mod, $argv);
 my($head, $blockend, $file_start, $file_end);
 
@@ -240,35 +248,52 @@ option --frame-classic-fold  --frame-classic-plain --ansifold
 option --frame-classic       --frame-classic-fold
 
 ##
-## EXPERIMENTAL: --frame-pages
+## EXPERIMENTAL: --frame-pages, --frame-cols
 ##
 
 # RPN
-define @TEXT_WIDTH  80
+define @TEXT_WIDTH  $ENV{GREPLE_FRAME_PAGES_WIDTH}
+define @MARGIN      $ENV{GREPLE_FRAME_PAGES_MARGIN}
 define @LINE_FIELD  8
 define @FRAME_GAP   3
-define @MARGIN      0
 define @COL_WIDTH   @TEXT_WIDTH:@LINE_FIELD:+:@FRAME_GAP:+
 define @COLUMN      @COL_WIDTH:/:INT:DUP:1:GE:EXCH:1:IF
 define @WIDTH       DUP:@COLUMN:/:@FRAME_GAP:-:@MARGIN:-
 
-define $PREFIX      '      │ '
-define $FOLD        ansifold --expand --discard=EL --padding --prefix $PREFIX
-define $COLUMN      ansicolumn --border=box -P
-define $FOLD_COLUMN $FOLD $<shift> --width=$<shift> | $COLUMN -C $<shift>
+define $FOLD \
+       ansifold --expand --discard=EL --padding \
+       --width =@WIDTH \
+       --prefix '      │ ' \
+       --boundary=$ENV{GREPLE_FRAME_PAGES_BOUNDARY} \
+       --linebreak=all --runin=@MARGIN --runout=@MARGIN
 
-option --frame-column-with-param \
-       --pf $FOLD_COLUMN
+define $COLS \
+       ansicolumn --border=box -U @COLUMN
 
-option --frame-pages-body \
-       &set(fold="--boundary=none --linebreak=all --run=@MARGIN") \
-       &set(width=@WIDTH,column=@COLUMN) \
-       --frame-column-with-param &get(fold,width,column)
+define $PAGES \
+       ansicolumn --border=box -P -C @COLUMN
 
-option --frame-pages \
-       --frame-pages-body \
+option --frame-set-params \
+       &set(width=@WIDTH)
+
+option --frame-col \
+       --frame-set-params \
+       --pf "$FOLD" \
        --frame-plain
 
+option --frame-pages \
+       --frame-set-params \
+       --pf "$FOLD | $PAGES" \
+       --frame-plain
+
+option --frame-cols \
+       --frame-set-params \
+       --pf "$FOLD | $COLS" \
+       --frame-plain
+
+option --frame-columns --frame-cols
+
 option --frame-pages-classic \
-       --frame-pages-body \
+       --frame-set-params \
+       --pf "$FOLD | $PAGES" \
        --frame-classic-plain
